# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

<!-- insertion marker -->
## [2.0.0](https://github.com/pawamoy/insiders/releases/tag/2.0.0) - 2025-01-16

<small>[Compare with 1.0.0](https://github.com/pawamoy/insiders/compare/1.0.0...2.0.0)</small>

### Code Refactoring

This project went under a complete refactoring. It provides much more features and now integrates the [`pypi-insiders`](https://pypi.org/project/pypi-insiders/) project. Let us know what you think of our CLI!

- Format Copier answers with context ([d056e3b](https://github.com/pawamoy/insiders/commit/d056e3b0439a2e0569cf6d1557f402e6eb297987) by Timothée Mazzucotelli).
- Only warn about unknown keys ([81b65d2](https://github.com/pawamoy/insiders/commit/81b65d257b4ff552749875ebe7d2ffd287c77434) by Timothée Mazzucotelli).
- Check for unknown config keys ([a343025](https://github.com/pawamoy/insiders/commit/a343025d15f6f3eb427484a016f0c75cd8faae65) by Timothée Mazzucotelli).
- Bind more options to the config ([85729fa](https://github.com/pawamoy/insiders/commit/85729fafef8dfb8ed9089c0fbec8938a5c057cc7) by Timothée Mazzucotelli).
- Improve index class ([1da458f](https://github.com/pawamoy/insiders/commit/1da458f172730ca42e4212e5c9bc8837a0177abc) by Timothée Mazzucotelli).
- Expose interception handler and its `allow` tuple ([d2e5396](https://github.com/pawamoy/insiders/commit/d2e5396f2197ad6e1665223ee008664d1d5e5449) by Timothée Mazzucotelli).
- Improve CLI and config ([05c2704](https://github.com/pawamoy/insiders/commit/05c2704daf28c91e59f698c68f284632960d1892) by Timothée Mazzucotelli).
- Completely refactor project ([7c080a3](https://github.com/pawamoy/insiders/commit/7c080a3cd8c8e932cf7369f866cd2a68af8bad00) by Timothée Mazzucotelli).
- Add library surface ([b2be4ef](https://github.com/pawamoy/insiders/commit/b2be4ef11b17d427bec3e466cf79ad33d1e5f472) by Timothée Mazzucotelli).

## [1.0.0](https://github.com/pawamoy/insiders/releases/tag/1.0.0) - 2024-10-12

<small>[Compare with first commit](https://github.com/pawamoy/insiders/compare/625c8abf651f00fe7101ad7cfdb060805a2e172f...1.0.0)</small>

### Features

- Make the project public! ([f6b3e08](https://github.com/pawamoy/insiders/commit/f6b3e0885ffda3b0a7c835307e243580b18c83bc) by Timothée Mazzucotelli).
